# Contributing to PySoundSphere

Contributions of all kinds are welcome.
Feature additions/requests, bug fixes/reports or documentation should be contributed via [issues](https://github.com/Nmstr/PySoundSphere/issues) and/or [pull requests](https://github.com/Nmstr/PySoundSphere/pulls).

## Contributing code

You should follow already established conventions.
All code should be tested before commiting/pulling.
In the commits and in pull requests you should clearly state what you are changing.
Code commits should be seperated from reformatting commits, if a lot of reformatting is done.

## Reporting Issues

Please use the premade issue template and fill out everything possible.
Images should be uploaded to Github and not third-party file hosting sites.
If necessary, add the images to a tar or zip archive.
Provide as many details as you can. These should include:
- What did you do?
- What did you expect to happen?
- What actually happened?
- What versions of PySoundSphere did you use?
- Anything else that might be important.

## Feature requests

Please use the premade template for feature requsts.
As above, images should be uploaded to Github directly.
A detailed description of the feature is required, which should include:
- Is it related to a problem? If so, which?
- Clearly describe the solution.
- Describe alternatives you've considered.
- Provide more context about the feature in question.

